==> komga_api_client-0.41.1.tar.gz: doc/LibraryControllerApi.md <==
# komga_api_client.api.LibraryControllerApi

## Load the API package
```dart
import 'package:komga_api_client/api.dart';
```

All URIs are relative to *http://localhost:8080*

Method | HTTP request | Description
------------- | ------------- | -------------
[**addOne**](LibraryControllerApi.md#addOne) | **post** /api/v1/libraries | 
[**analyze**](LibraryControllerApi.md#analyze) | **post** /api/v1/libraries/{libraryId}/analyze | 
[**deleteOne**](LibraryControllerApi.md#deleteOne) | **delete** /api/v1/libraries/{id} | 
[**getAll**](LibraryControllerApi.md#getAll) | **get** /api/v1/libraries | 
[**getOne**](LibraryControllerApi.md#getOne) | **get** /api/v1/libraries/{id} | 
[**refreshMetadata**](LibraryControllerApi.md#refreshMetadata) | **post** /api/v1/libraries/{libraryId}/metadata/refresh | 
[**scan**](LibraryControllerApi.md#scan) | **post** /api/v1/libraries/{libraryId}/scan | 


# **addOne**
> LibraryDto addOne(libraryCreationDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var libraryCreationDto = new LibraryCreationDto(); // LibraryCreationDto | 

try { 
    var result = api_instance.addOne(libraryCreationDto);
    print(result);
} catch (e) {
    print("Exception when calling LibraryControllerApi->addOne: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **libraryCreationDto** | [**LibraryCreationDto**](LibraryCreationDto.md)|  | 

### Return type

[**LibraryDto**](LibraryDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **analyze**
> analyze(libraryId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var libraryId = 789; // int | 

try { 
    api_instance.analyze(libraryId);
} catch (e) {
    print("Exception when calling LibraryControllerApi->analyze: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **libraryId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteOne**
> deleteOne(id)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var id = 789; // int | 

try { 
    api_instance.deleteOne(id);
} catch (e) {
    print("Exception when calling LibraryControllerApi->deleteOne: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAll**
> List<LibraryDto> getAll()



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();

try { 
    var result = api_instance.getAll();
    print(result);
} catch (e) {
    print("Exception when calling LibraryControllerApi->getAll: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<LibraryDto>**](LibraryDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getOne**
> LibraryDto getOne(id)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var id = 789; // int | 

try { 
    var result = api_instance.getOne(id);
    print(result);
} catch (e) {
    print("Exception when calling LibraryControllerApi->getOne: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]

### Return type

[**LibraryDto**](LibraryDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **refreshMetadata**
> refreshMetadata(libraryId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var libraryId = 789; // int | 

try { 
    api_instance.refreshMetadata(libraryId);
} catch (e) {
    print("Exception when calling LibraryControllerApi->refreshMetadata: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **libraryId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **scan**
> scan(libraryId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var libraryId = 789; // int | 

try { 
    api_instance.scan(libraryId);
} catch (e) {
    print("Exception when calling LibraryControllerApi->scan: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **libraryId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> komga_api_client-37.0.0.tar.gz: doc/LibraryControllerApi.md <==
# komga_api_client.api.LibraryControllerApi

## Load the API package
```dart
import 'package:komga_api_client/api.dart';
```

All URIs are relative to *https://demo.komga.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**addOne**](LibraryControllerApi.md#addOne) | **post** /api/v1/libraries | 
[**analyze1**](LibraryControllerApi.md#analyze1) | **post** /api/v1/libraries/{libraryId}/analyze | 
[**deleteOne**](LibraryControllerApi.md#deleteOne) | **delete** /api/v1/libraries/{id} | 
[**getAll**](LibraryControllerApi.md#getAll) | **get** /api/v1/libraries | 
[**getOne**](LibraryControllerApi.md#getOne) | **get** /api/v1/libraries/{id} | 
[**refreshMetadata1**](LibraryControllerApi.md#refreshMetadata1) | **post** /api/v1/libraries/{libraryId}/metadata/refresh | 
[**scan**](LibraryControllerApi.md#scan) | **post** /api/v1/libraries/{libraryId}/scan | 


# **addOne**
> LibraryDto addOne(libraryCreationDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var libraryCreationDto = new LibraryCreationDto(); // LibraryCreationDto | 

try { 
    var result = api_instance.addOne(libraryCreationDto);
    print(result);
} catch (e) {
    print("Exception when calling LibraryControllerApi->addOne: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **libraryCreationDto** | [**LibraryCreationDto**](LibraryCreationDto.md)|  | 

### Return type

[**LibraryDto**](LibraryDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **analyze1**
> analyze1(libraryId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var libraryId = 789; // int | 

try { 
    api_instance.analyze1(libraryId);
} catch (e) {
    print("Exception when calling LibraryControllerApi->analyze1: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **libraryId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteOne**
> deleteOne(id)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var id = 789; // int | 

try { 
    api_instance.deleteOne(id);
} catch (e) {
    print("Exception when calling LibraryControllerApi->deleteOne: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAll**
> List<LibraryDto> getAll()



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();

try { 
    var result = api_instance.getAll();
    print(result);
} catch (e) {
    print("Exception when calling LibraryControllerApi->getAll: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<LibraryDto>**](LibraryDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getOne**
> LibraryDto getOne(id)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var id = 789; // int | 

try { 
    var result = api_instance.getOne(id);
    print(result);
} catch (e) {
    print("Exception when calling LibraryControllerApi->getOne: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]

### Return type

[**LibraryDto**](LibraryDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **refreshMetadata1**
> refreshMetadata1(libraryId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var libraryId = 789; // int | 

try { 
    api_instance.refreshMetadata1(libraryId);
} catch (e) {
    print("Exception when calling LibraryControllerApi->refreshMetadata1: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **libraryId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **scan**
> scan(libraryId)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new LibraryControllerApi();
var libraryId = 789; // int | 

try { 
    api_instance.scan(libraryId);
} catch (e) {
    print("Exception when calling LibraryControllerApi->scan: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **libraryId** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
